onVisibilityGained method
void
onVisibilityGained()
It means the widget is now visible within your app.
Implementation
void onVisibilityGained() {}
It means the widget is now visible within your app.
void onVisibilityGained() {}